@@ -25,6 +25,8 @@ from dataclasses import dataclass, field
 from enum import Enum
 from typing import Any, Dict, List, Optional, Union
 
+from .scoped_name import ScopedName
+
 
 class AccessSpecifier(Enum):
     """ The class access specifiers. """
@@ -606,181 +608,6 @@ class ValueType(Enum):
     EMPTY = 6
 
 
-class ScopedName:
-    """ Encapsulate a scoped name. """
-
-    def __init__(self, name):
-        """ Initialise the scoped name. """
-
-        if isinstance(name, list):
-            # This use is internal to this class.
-            self._name = name
-        elif isinstance(name, ScopedName):
-            # Make a copy of another ScopedName object.
-            self._name = list(name._name)
-        else:
-            # Create a simple name.
-            self._name = [name]
-
-    def __eq__(self, other):
-        """ Compare with another scoped name for equality. """
-
-        if isinstance(other, ScopedName):
-            return self._name == other._name
-
-        return NotImplemented
-
-    def __delitem__(self, index):
-        """ Remove the requested name. """
-
-        del self._name[self._normalised_index(index)]
-
-    def __getitem__(self, index):
-        """ Get the requested name. """
-
-        return self._name[self._normalised_index(index)]
-
-    def __len__(self):
-        """ Return the length of the name, ie. the number of indivual names.
-        """
-
-        nr_names = len(self._name)
-
-        if self.is_absolute:
-            nr_names -= 1
-
-        return nr_names
-
-    def __lt__(self, other):
-        """ Compare with another scoped name to allow lists to be sorted. """
-
-        if isinstance(other, ScopedName):
-            return self._name < other._name
-
-        return NotImplemented
-
-    def __setitem__(self, index, name):
-        """ Set the requested name. """
-
-        self._name[self._normalised_index(index)] = name
-
-    def __str__(self):
-        """ Return the C++ string representation. """
-
-        # The special treatment is a hack to simplify how the result is used.
-        # We ignore any leading '::' and truncate the conversion if we think we
-        # are converting an encoded template name (ie. we find a word that
-        # starts with a digit).
-        s_l = []
-        for s in self:
-            if s[0].isdigit():
-                break
-
-            s_l.append(s)
-
-        return '::'.join(s_l)
-
-    @property
-    def absolute(self):
-        """ Return an absolute version of the name. """
-
-        if self.is_absolute:
-            return self
-
-        copy = type(self)(self)
-        copy.make_absolute()
-
-        return copy
-
-    def append(self, name):
-        """ Append a simple name. """
-
-        self._name.append(name)
-
-    @property
-    def base_name(self):
-        """ The base name of the scoped name. """
-
-        return self._name[-1]
-
-    @property
-    def is_absolute(self):
-        """ True if the scoped name is absolute. """
-
-        return self._name[0] == ''
-
-    @property
-    def is_simple(self):
-        """ Return True if the name is simple, ie. relative and unscoped. """
-
-        return len(self) == 1
-
-    def matches(self, scoped_name, scope=None):
-        """ Return True if a scoped name matches this taking account of an
-        optional scope if the scoped name is relative.
-        """
-
-        assert self.is_absolute
-
-        # Check for the simple case.
-        if scoped_name.is_absolute:
-            return self == scoped_name
-
-        # Try each scope, inner to outer.
-        while scope is not None:
-            fq_name = ScopedName(scope.iface_file.fq_cpp_name)
-            fq_name._name.extend(scoped_name._name)
-
-            if self == fq_name:
-                return True
-
-            scope = scope.scope
-
-        # Treat the name as if it were absolute.
-        return self._name[1:] == scoped_name._name
-
-    def make_absolute(self):
-        """ Make sure the scoped name is absolute. """
-
-        if self._name[0] != '':
-            self._name.insert(0, '')
-
-    @classmethod
-    def parse(cls, raw):
-        """ Return a ScopedName object by parsing a raw string. """
-
-        return cls(raw.split('::'))
-
-    def prepend(self, scoped_name):
-        """ Prepend a scoped name. """
-
-        new_name = list(scoped_name._name)
-        new_name.extend(self._name)
-        self._name = new_name
-
-    @property
-    def scope(self):
-        """ The scoped name that is the enclosing scope of this one.  It will
-        be None if there isn't one.
-        """
-
-        if len(self) == 1:
-            return None
-
-        return type(self)(self._name[:-1])
-
-    def _normalised_index(self, index):
-        """ Return a normalised index. """
-
-        if not isinstance(index, int):
-            raise TypeError("'{}' is an invalid index".format(type(index)))
-
-        if index >= 0 and self.is_absolute:
-            index += 1
-
-        return index
-
-
 @dataclass
 class Argument:
     """ Encapsulate a callable argument (or return value or variable type). """
@@ -965,8 +792,8 @@ class Extract:
     # The order.  A negative value implies the part is appended to the extract.
     order: int
 
-    # The actual part of the extract.
-    part: CodeBlock
+    # The text of the extract part.
+    text: str
 
 
 @dataclass
@@ -1235,6 +1062,9 @@ class Module:
     # The code specified by any %PreInitialisationCode directives.
     preinitialisation_code: List[CodeBlock] = field(default_factory=list)
 
+    # The name of the module. (resolver)
+    py_name: Optional[str] = None
+
     # Set if the generated bindings are Py_ssize_t clean.
     py_ssize_t_clean: bool = False
 
@@ -1459,6 +1289,9 @@ class Specification:
     # Set if the specification is strict.
     is_strict: bool
 
+    # The name of the sip module.
+    sip_module: str
+
     # Set if the bindings are for C rather than C++.
     c_bindings: bool = False
 
@@ -1544,23 +1377,15 @@ class ThrowArguments:
     arguments: Optional[List['WrappedException']] = None
 
 
-@dataclass
-class TypeHint:
-    """ Encapsulate a PEP 484 type hint. """
-
-    # The text of the hint.
-    text: str
-
-
 @dataclass
 class TypeHints:
     """ Encapsulate a set of PEP 484 type hints for a type. """
 
     # The type hint when used to pass a value into a callable.
-    hint_in: Optional[TypeHint]
+    hint_in: Optional[str]
 
     # The type hint used to return a value from a callable.
-    hint_out: Optional[TypeHint]
+    hint_out: Optional[str]
 
     # The representation of a default value in a type hint.
     default_value: Optional[str]
